<?php
// $Id: drupal_developer.profile,v 1.9 2008/10/25 11:32:04 snufkin Exp $
/**
 * @file
 * Install profile for a developer setup
 */

function drupal_developer_profile_modules() {
  return array(
    // enable core modules
    'user', 'filter', 'block', 'node', 'taxonomy', 'comment', 'profile', 'menu',
    // enable devel modules
    'devel', 'devel_generate', 
    // enable admin menu
     'admin_menu',
    // enable coder
    'coder',
    // enable simpletest
    'simpletest'
  );
}

function drupal_developer_profile_details() {
  return array(
    'name' => 'Drupal developer profile',
    'description' => 'Profile containing and installing development modules. WARNING! It contains dangerous user permissions, for development purposes only.',
  );
}

function drupal_developer_profile_tasks(&$task, $url) {
  // copied from default.profile
  $types = array(
    array(
      'type' => 'page',
      'name' => st('Page'),
      'module' => 'node',
      'description' => st("A <em>page</em>, similar in form to a <em>story</em>, is a simple method for creating and displaying information that rarely changes, such as an \"About us\" section of a website. By default, a <em>page</em> entry does not allow visitor comments and is not featured on the site's initial home page."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
      'help' => '',
      'min_word_count' => '',
    ),
    array(
      'type' => 'story',
      'name' => st('Story'),
      'module' => 'node',
      'description' => st("A <em>story</em>, similar in form to a <em>page</em>, is ideal for creating and displaying content that informs or engages website visitors. Press releases, site announcements, and informal blog-like entries may all be created with a <em>story</em> entry. By default, a <em>story</em> entry is automatically featured on the site's initial home page, and provides the ability to post comments."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
      'help' => '',
      'min_word_count' => '',
    ),
  );

  foreach ($types as $type) {
    $type = (object) _node_type_set_defaults($type);
    node_type_save($type);
  }

  // Default page to not be promoted and have comments disabled.
  variable_set('node_options_page', array('status'));
  variable_set('comment_page', COMMENT_NODE_DISABLED);

  // Don't display date and author information for page nodes by default.
  $theme_settings = variable_get('theme_settings', array());
  $theme_settings['toggle_node_info_page'] = FALSE;
  variable_set('theme_settings', $theme_settings);

  // Update the menu router information.
  menu_rebuild();
}

/*
 * Implementation of hook_form_alter().
 */
function drupal_developer_form_alter(&$form, $form_state, $form_id) {
  if ($form_id == 'install_configure') {
    // Set default for site name field.
    $form['site_information']['site_name']['#default_value'] = t('Drupal Devel');
    $form['site_information']['site_mail']['#default_value'] = 'drupal@localhost';
    $form['admin_account']['account']['name']['#default_value'] = 'drupal';
    $form['admin_account']['account']['mail']['#default_value'] = 'drupal@localhost';
    $form['admin_account']['account']['pass']['#type'] = 'textfield';
    $form['admin_account']['account']['pass']['#default_value'] = 'drupal';
  }
}


function drupal_developer_profile_final() {
// adding default content types, otherwise they are not created
  $types = array(
    array(
      'type' => 'page',
      'name' => t('Page'),
      'module' => 'node',
      'description' => t('If you want to add a static page, like a contact page or an about page, use a page.'),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
    ),
    array(
      'type' => 'story',
      'name' => t('Story'),
      'module' => 'node',
      'description' => t('Stories are articles in their simplest form: they have a title, a teaser and a body, but can be extended by other modules. The teaser is part of the body too. Stories may be used as a personal blog or for news articles.'),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
    ),
  );

  foreach ($types as $type) {
    $type = (object) _node_type_set_defaults($type);
    node_type_save($type);
  }

  // Default page to not be promoted and have comments disabled.
  variable_set('node_options_page', array('status'));
  variable_set('comment_page', COMMENT_NODE_DISABLED);

// adding devel blocks

  db_query("INSERT INTO {blocks} VALUES ('devel','2','garland',1,0,'right',0,0,0,'','')");
  db_query("INSERT INTO {blocks} VALUES ('devel','1','garland',1,0,'right',0,0,0,'','')");
  db_query("INSERT INTO {blocks} VALUES ('devel','0','garland',1,0,'right',0,0,0,'','')");
  // adding permissions for anonym to access content, to auth to post comments, and switch users
  // WARNING unsafe settings for live site ------------------------------------------'''''''''
  db_query("UPDATE {permission} SET perm = 'access comments, access content' WHERE rid = 1");
  db_query("UPDATE {permission} SET perm = 'access comments, post comments, post comments without approval, switch users, access content' WHERE rid = 2");
  // Add admin user: drupal:drupal
  $uid = db_next_id('{users}_uid');
  db_query("INSERT INTO {users} VALUES( %d,'drupal','08d15a4aef553492d8971cdd5198f314','drupal@localhost',0,0,0,'','','120 7223939',1207223949,0,1,'0','','','drupal@localhost','a:0:{}')", $uid);

  return t('Welcome to <a href="@url>your new development install</a>. Username:password is drupal:drupal. Happy coding.', array('@url' => url('')));

}
